#!/usr/bin/env node

'use strict';

var path =  require('path');
var notify = require('growl');

process.stdin.pipe(process.stdout);

function message (failed, total) {
    if (failed) {
        return failed + ' of ' + total + ' tests failed';
    } else {
        return total + ' tests passed';
    }
}

function image (name) {
    return path.join(__dirname, './images/' , name + '.png');
}

function growlOptions (results) {
    var failed = results.fail.length + results.errors.length;
    var total = results.plan.end;

    return {
        name: 'tap',
        title: failed ? 'Failed' : 'Passed',
        image: image(failed ? 'error' : 'ok'),
        message: message(failed, total)
    };
}

function init() {
    var finished = require('tap-finished');

    var notifier = finished(function (results) {
        var options = growlOptions(results);
        notify(options.message, options);
        setImmediate(init); // keep watching for next test run
    });

    process.stdin.pipe(notifier);
}

init();
